==> haskell-project-template-0.2.0.1-131-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0.1
id: project-template-0.2.0.1-IsRd2UUg6SHFeH3LOoqdPj
key: project-template-0.2.0.1-IsRd2UUg6SHFeH3LOoqdPj
license: BSD-3-Clause
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
abi: b4af5d6bad8e2a3f437296bb1e4335bc
exposed: True
exposed-modules:
    Text.ProjectTemplate
import-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/project-template-0.2.0.1
hs-libraries: HSproject-template-0.2.0.1-IsRd2UUg6SHFeH3LOoqdPj
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bytestring-0.10.8.2 conduit-1.3.1.1-kLctWFUOpzEzkNMMsWt8W
    conduit-extra-1.3.1.1-9ykQTbsUQTG8xrFoJG8x1j containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0.1-134-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0.1
id: project-template-0.2.0.1-6uZq3GlIOX58lt0hPFK3Sy
key: project-template-0.2.0.1-6uZq3GlIOX58lt0hPFK3Sy
license: BSD-3-Clause
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
abi: 7552083d95b5f527cb718b3004f783e1
exposed: True
exposed-modules:
    Text.ProjectTemplate
import-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/project-template-0.2.0.1
hs-libraries: HSproject-template-0.2.0.1-6uZq3GlIOX58lt0hPFK3Sy
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
    bytestring-0.10.8.2 conduit-1.3.1.1-6vw9UyMXP3BIfd0ftlTGKn
    conduit-extra-1.3.1.1-7QjwD9yJ3C7J34fDkPiQun containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    resourcet-1.2.2-9oU1YIUEv382vhkW8K0jVF text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
